/**
 * Compile a set of routes.
 * All properties of the original routes are preserved
 * @param {Route[]} routes
 * @return {CompiledRoute[]}
 */
export function compile(routes: Route[]): CompiledRoute[];
/**
 * Generate regex with priority.
 * @param {Route} route
 * @return {CompiledRoute}
 */
export function pathToRegexp(route: Route): CompiledRoute;
/**
 * Find best match for a given path.
 * Decodes params into an object.
 * @param {CompiledRoute[]} compiled
 * @param {string} path
 * @return {Match} match
 */
export function matcher(compiled: CompiledRoute[], path: string): Match;
/**
 * One single route
 * @typedef {Object} Route
 * @property {string} path
 */
/**
 * Result of a path compilation
 * priorities for each path component
 * - :param       {@link PARAM}
 * - match * or ? {@link WILDCARD}
 * - plain        {@link PLAIN}
 * @typedef  {Object} CompiledRoute
 * @property {string} path
 * @property {RegExp} regex for later checking and params extraction
 * @property {string[]} keys all keys found in the route
 * @property {number} priority order in which to check
 */
/**
 * Result of a match
 * @typedef  {Object} Match
 * @property {Route} [route] as given to the compiler, undefined if no matching route was found
 * @property {Object} params extracted from the path
 */
/**
 * Prioritiy for a plain path component
 */
export const PLAIN: 100;
/**
 * Prioritiy for a path component with a wildcard '*'
 */
export const WILDCARD: 10;
/**
 * Prioritiy for a parameter path component
 */
export const PARAM: 1;
/**
 * One single route
 */
export type Route = {
    path: string;
};
/**
 * Result of a path compilation
 * priorities for each path component
 * - :param       {@link PARAM}
 * - match * or ? {@link WILDCARD}
 * - plain        {@link PLAIN}
 */
export type CompiledRoute = {
    path: string;
    /**
     * for later checking and params extraction
     */
    regex: RegExp;
    /**
     * all keys found in the route
     */
    keys: string[];
    /**
     * order in which to check
     */
    priority: number;
};
/**
 * Result of a match
 */
export type Match = {
    /**
     * as given to the compiler, undefined if no matching route was found
     */
    route?: Route;
    /**
     * extracted from the path
     */
    params: any;
};
